@@ -49,7 +49,7 @@ static gint gnome_printer_selector_construct (GPAWidget *gpa_widget);
 static void gnome_printer_selector_finalize (GObject *object);
 
 static GtkWidget *gpw_create_label (GtkTable *table, gint l, gint r, gint t, gint b, const gchar *text, GtkWidget *label_for);
-static GtkWidget *gpw_create_label_with_mnemonic (GtkTable *table, gint l, gint r, gint t, gint b, const gchar *text, GtkWidget *mnemonic_widget, gboolean add_relation);
+static GtkWidget *gpw_create_label_with_mnemonic (GtkTable *table, gint l, gint r, gint t, gint b, const gchar *text, GtkWidget *mnemonic_widget);
 
 static void gpw_configure_clicked (GtkWidget *widget, GPAWidget *gpaw);
 
@@ -117,10 +117,8 @@ gnome_printer_selector_construct (GPAWidget *gpa_widget)
 {
 	GnomePrinterSelector *gpw;
 	GtkWidget *f, *t, *b, *l, *h, *v, *label;
-	AtkRelationSet *relation_set;
-	AtkRelation *relation;
-	AtkObject *relation_targets[2];
-	AtkObject *atko, *label_atko, *menu_atko, *button_atko;
+	AtkObject *atko;
+	gchar *text;
 
 	gpw = GNOME_PRINTER_SELECTOR (gpa_widget);
 
@@ -129,7 +127,9 @@ gnome_printer_selector_construct (GPAWidget *gpa_widget)
 	f = gtk_frame_new ("");
 	gtk_frame_set_shadow_type (GTK_FRAME (f), GTK_SHADOW_NONE);
 	label = gtk_label_new ("");
-	gtk_label_set_markup (GTK_LABEL (label), _("<b>Printer</b>"));
+	text = g_strdup_printf ("<b>%s</b>", _("Printer"));
+	gtk_label_set_markup (GTK_LABEL (label), text);
+	g_free (text);
 	gtk_frame_set_label_widget (GTK_FRAME (f), label);
 	gtk_widget_show (label);
 
@@ -190,56 +190,25 @@ gnome_printer_selector_construct (GPAWidget *gpa_widget)
 			  GPS_PAD, GPS_PAD);
 	gpw_create_label_with_mnemonic (GTK_TABLE (t), 0, 1, 0, 1,
 					_("Pr_inter:"),
-					((GPAPrinterSelector*) gpw->printers)->menu, TRUE);
+					((GPAPrinterSelector*) gpw->printers)->menu);
 
 	gpw->settings = gpa_widget_new (GPA_TYPE_SETTINGS_SELECTOR, NULL);
 	gtk_widget_show (gpw->settings);
 	gtk_table_attach (GTK_TABLE (t), gpw->settings, 1, 2, 1, 2,
 			  GTK_FILL, 0,
 			  GPS_PAD, GPS_PAD);
-	l = gpw_create_label_with_mnemonic (GTK_TABLE (t), 0, 1, 1, 2,
+	gpw_create_label_with_mnemonic (GTK_TABLE (t), 0, 1, 1, 2,
 					    _("_Settings:"),
-					    ((GPASettingsSelector*) gpw->settings)->menu, TRUE);
+					    ((GPASettingsSelector*) gpw->settings)->menu);
 
 	gpw->transport = gpa_widget_new (GPA_TYPE_TRANSPORT_SELECTOR, NULL);
 	gtk_widget_show (gpw->transport);
 	gtk_table_attach (GTK_TABLE (t), gpw->transport, 1, 3, 2, 3,
 			  GTK_FILL , 0,
 			  GPS_PAD, GPS_PAD);
-	gpw_create_label_with_mnemonic (GTK_TABLE (t), 0, 1, 2, 3,
+	l = gpw_create_label_with_mnemonic (GTK_TABLE (t), 0, 1, 2, 3,
 					_("_Location:"),
-					((GPATransportSelector*) gpw->transport)->menu, FALSE);
-	/* Add a LABEL_FOR relation from the Location label to the option menu */
-	label_atko = gtk_widget_get_accessible (l);
-	menu_atko  = gtk_widget_get_accessible (((GPATransportSelector*) gpw->transport)->menu);
-	button_atko = gtk_widget_get_accessible (((GPATransportSelector*) gpw->transport)->file_button);
-
-	relation_set = atk_object_ref_relation_set (label_atko);
-	relation_targets[0] = menu_atko;
-	relation_targets[1] = button_atko;
-	relation = atk_relation_new (relation_targets, 2,
-				     ATK_RELATION_LABEL_FOR);
-	atk_relation_set_add (relation_set, relation);
-	g_object_unref (G_OBJECT (relation));
-	g_object_unref (G_OBJECT (relation_set));
-
-	/* Add LABELLED_BY relations the other way round. */
-	relation_set = atk_object_ref_relation_set (menu_atko);
-	relation_targets[0] = label_atko;
-	relation = atk_relation_new (relation_targets, 1,
-				     ATK_RELATION_LABELLED_BY);
-	atk_relation_set_add (relation_set, relation);
-	g_object_unref (G_OBJECT (relation));
-	g_object_unref (G_OBJECT (relation_set));
-
-	relation_set = atk_object_ref_relation_set (button_atko);
-	relation_targets[0] = label_atko;
-	relation = atk_relation_new (relation_targets, 1,
-				     ATK_RELATION_LABELLED_BY);
-	atk_relation_set_add (relation_set, relation);
-	g_object_unref (G_OBJECT (relation));
-	g_object_unref (G_OBJECT (relation_set));
-
+					((GPATransportSelector*) gpw->transport)->menu);
 	return TRUE;
 }
 
@@ -354,33 +323,14 @@ gpw_create_label (GtkTable *table, gint l, gint r, gint t, gint b, const gchar *
 }
 
 static GtkWidget *
-gpw_create_label_with_mnemonic (GtkTable *table, gint l, gint r, gint t, gint b, const gchar *text, GtkWidget *mnemonic_widget, gboolean add_relation)
+gpw_create_label_with_mnemonic (GtkTable *table, gint l, gint r, gint t, gint b, const gchar *text, GtkWidget *mnemonic_widget)
 {
-	GtkWidget *w;
-	AtkRelationSet *relation_set;
-	AtkRelation *relation;
-	AtkObject *relation_targets[1];
-	AtkObject *atko;
-
-	w = gtk_label_new_with_mnemonic (text);
+	GtkWidget *w = gtk_label_new_with_mnemonic (text);
 	gtk_widget_show (w);
 	gtk_misc_set_alignment (GTK_MISC (w), 1.0, 0.5);
 	gtk_table_attach (table, w, l, r, t, b, GTK_FILL | GTK_EXPAND, GTK_FILL | GTK_EXPAND, GPS_PAD, GPS_PAD);
 	gtk_label_set_mnemonic_widget ((GtkLabel *) w, mnemonic_widget);
 
-	if (add_relation) {
-		/* Add a LABELLED_BY relation from the mnemonic widget to the
-		   label. */
-		atko = gtk_widget_get_accessible (mnemonic_widget);
-		relation_set = atk_object_ref_relation_set (atko);
-		relation_targets[0] = gtk_widget_get_accessible (w);
-		relation = atk_relation_new (relation_targets, 1,
-					     ATK_RELATION_LABELLED_BY);
-		atk_relation_set_add (relation_set, relation);
-		g_object_unref (G_OBJECT (relation));
-		g_object_unref (G_OBJECT (relation_set));
-	}
-
 	return w;
 }
 
@@ -404,3 +354,11 @@ gpw_configure_clicked (GtkWidget *widget, GPAWidget *gpaw)
 	
 	gtk_widget_destroy (GTK_WIDGET (gpcd));
 }
+
+
+gboolean           
+gnome_printer_selector_check_consistency (GnomePrinterSelector *psel)
+{
+	return gpa_transport_selector_check_consistency 
+		(GPA_TRANSPORT_SELECTOR (psel->transport));
+}
